#
# spec file for package python-azure-agent
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%define pythons %{primary_python}
%elif 0%{?suse_version} = 1315
%define pythons python
%else
%define pythons python3
%endif
%global _sitelibdir %{%{pythons}_sitelib}

Name:           python-azure-agent
Version:        2.12.0.4
Release:        1.1
Summary:        Microsoft Azure Linux Agent
License:        Apache-2.0
Group:          System/Daemons
URL:            https://github.com/Azure/WALinuxAgent
Source0:        WALinuxAgent-%{version}.tar.gz
Patch7:         reset-dhcp-deprovision.patch
Patch8:         paa_12_sp5_rdma_no_ext_driver.patch
# PATCH-FIX-UPSTREAM gh#Azure/WALinuxAgent#2741
Patch9:         remove-mock.patch
# PATCH-FIX-UPSTREAM gh#Azure/WALinuxAgent#3158
Patch11:        agent-btrfs-use-f.patch
Patch12:        paa_direct_exec_in_service.patch
BuildRequires:  dos2unix

BuildRequires:  %{pythons}-pip
BuildRequires:  %{pythons}-setuptools
BuildRequires:  %{pythons}-wheel
BuildRequires:  distribution-release
BuildRequires:  openssl
BuildRequires:  python-rpm-macros
%if 0%{?suse_version} > 1315
BuildRequires:  %{pythons}-distro
%else
BuildRequires:  %{pythons}-xml
%endif
BuildRequires:  pkgconfig(udev)
Requires:       eject
Requires:       grep
Requires:       iptables
Requires:       logrotate
Requires:       openssh
Requires:       openssl
Requires:       pwdutils
Requires:       systemd
Requires:       sysvinit-tools
%if 0%{?suse_version} && 0%{?suse_version} <= 1500
Requires:       wicked
%endif
Requires:       %{pythons}-pyasn1
Requires:       %{pythons}-xml
%if 0%{?suse_version} > 1315
Requires:       %{pythons}-distro
%endif
Requires:       sudo
Requires:       util-linux

# Package renamed in SLE 12, do not remove Provides, Obsolete directives
# until after SLE 12 EOL
Provides:       WALinuxAgent = %{version}
Obsoletes:      WALinuxAgent < %{version}

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The azure-agent supports the provisioning and running of Linux
VMs in the Microsoft Azure Public Cloud and Microsoft Azure Stack private
cloud. This package should be installed on Linux disk
images that are built to run withing the Microsoft Azure or
Microsoft Azure Stack framework.

%package test
Summary:        Unit tests
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       %{pythons}-pytest
Requires:       openssl
%if 0%{?suse_version} == 1315
Requires:       %{pythons}-mock
%endif

%description test
Unit tests for python-azure-agent.

%package config-default
Summary:        Default upstream configuration
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Conflicts:      waagent-config
Provides:       waagent-config

%description config-default
The default configuration for the agent as supplied by upstream for SUSE

%package config-server
Summary:        SUSE specific configuration for server products
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Conflicts:      waagent-config
Provides:       waagent-config

%description config-server
Modified waagent.conf file to meet SUSE policies and SUSE image build
setup

%package config-hpc
Summary:        SUSE specific configuration for HPC
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Conflicts:      waagent-config
Provides:       waagent-config

%description config-hpc
Modified waagent.conf file to meet SUSE policies and SUSE image build
setup

%package config-micro
Summary:        SUSE specific configuration for Micro
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Conflicts:      waagent-config
Provides:       waagent-config

%description config-micro
Modified waagent.conf file to meet SUSE policies and SUSE image build
setup

%prep
%setup -q -n WALinuxAgent-%{version}
%patch -P 7
%patch -P 8 -p1
%patch -P 9 -p1
%patch -P 11
%patch -P 12

%build
# We have an insane veriation in the way we identify our distros from suse,
# sles, opensuse, openSUSE Tumbleweed and who knows what else. This makes it
# for all intend and purposes impractical to follow the bouncing ball and keep
# updating the upstream detection code. We use setup.py to be able to
# pass an argument during install
%python_build

%install
%python_exec setup.py install --prefix=%{_prefix} --lnx-distro='suse' --root=%{buildroot}
%if 0%{?suse_version} > 1315
rm %{buildroot}%{_sbindir}/waagent2.0
%python3_fix_shebang
%endif

# Config file flavor setup
cp %{buildroot}%{_sysconfdir}/waagent.conf %{buildroot}%{_sysconfdir}/waagent.conf.default
# No autoupdate of binaries for any SUSE product
sed -i -e "s/# AutoUpdate.Enabled=y/AutoUpdate.Enabled=n/" %{buildroot}%{_sysconfdir}/waagent.conf
# Common settings for most SUSE products
# Generate all supported SSH host key types
sed -i -e "s/SshHostKeyPairType=rsa/SshHostKeyPairType=auto/" %{buildroot}%{_sysconfdir}/waagent.conf
# We use clod-init
sed -i -e "s/Provisioning.Agent=auto/Provisioning.Agent=cloud-init/" %{buildroot}%{_sysconfdir}/waagent.conf
# Leave the ephemeral disk handling to cloud-init
sed -i -e "s/ResourceDisk.Format=y/ResourceDisk.Format=n/" %{buildroot}%{_sysconfdir}/waagent.conf
cp %{buildroot}%{_sysconfdir}/waagent.conf %{buildroot}%{_sysconfdir}/waagent.conf.server
# HPC setup is addition to SUSE server configuration
# While there is no more specific driver we still need to enable
# RDMA to make the logic in the agent set up the IB interface
sed -i -e "s/# OS.EnableRDMA=y/OS.EnableRDMA=y/" %{buildroot}%{_sysconfdir}/waagent.conf
cp %{buildroot}%{_sysconfdir}/waagent.conf %{buildroot}%{_sysconfdir}/waagent.conf.hpc
# Micro setup
# Undo the HPC change
sed -i -e "s/OS.EnableRDMA=y/# OS.EnableRDMA=y/" %{buildroot}%{_sysconfdir}/waagent.conf
%if 0%{?sle_version} && 0%{?sle_version} < 150500
# Use Ignition/Afterburn in Micro < 5.5
sed -i -e "s/Provisioning.Agent=cloud-init/Provisioning.Agent=disabled/" %{buildroot}%{_sysconfdir}/waagent.conf
%endif
# No extension support for transactional-upfdate systems
# There's an inherant bug in that root password reset is also treated via this
# switch
sed -i -e "s/Extensions.Enabled=y/Extensions.Enabled=n/" %{buildroot}%{_sysconfdir}/waagent.conf
mv %{buildroot}%{_sysconfdir}/waagent.conf %{buildroot}%{_sysconfdir}/waagent.conf.micro

ln -s service %{buildroot}%{_sbindir}/rcwaagent
mkdir -p %{buildroot}/%{_unitdir}

# Deal with logic embeded in the code that puts the unit file where we do not
# want it, sometimes (depending on teh build environment)
if [ -e %{buildroot}/lib/systemd/system ]; then
mv %{buildroot}/lib/systemd/system/* %{buildroot}/%{_unitdir}
fi

### udev rules
mkdir -p %{buildroot}%{_prefix}/lib/udev/rules.d
mv %{buildroot}%{_sysconfdir}/udev/rules.d/* %{buildroot}%{_prefix}/lib/udev/rules.d/
### log file ghost
mkdir -p  %{buildroot}/%{_localstatedir}/log
touch %{buildroot}/%{_localstatedir}/log/waagent.log
### naming issues
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_distconfdir}/logrotate.d
mv %{buildroot}/%{_sysconfdir}/logrotate.d/waagent.logrotate %{buildroot}/%{_distconfdir}/logrotate.d/waagent
%else
mv %{buildroot}/%{_sysconfdir}/logrotate.d/waagent.logrotate %{buildroot}/%{_sysconfdir}/logrotate.d/waagent
%endif

# install tests
cp -r tests %{buildroot}/%{_sitelibdir}/azurelinuxagent

%pre
%service_add_pre waagent.service
# Handle the case when the -config-* package is not installed, we want to
# preserver the previousl config file that was flavor customized during
# image build
if [ -e %{_sysconfdir}/waagent.conf ]; then
    cp -Z %{_sysconfdir}/waagent.conf %{_sysconfdir}/waagent.conf.bak
fi

%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/etc; save any old .rpmsave
for i in logrotate.d/waagent ; do
   test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done
%endif

%posttrans
# Do not clobber the config if it was installed from a config package, but
# put the oldfile back if we do not have another config file
if [ ! -e %{_sysconfdir}/waagent.conf ]; then
    if [ -e %{_sysconfdir}/waagent.conf.bak ]; then
        mv -Z %{_sysconfdir}/waagent.conf.bak %{_sysconfdir}/waagent.conf
        #restart the waagent.service again the restert in post failed due
        # to missing config
        systemctl try-restart waagent.service
    # Making the assumption that the rpmsave file was generated because of
    # of the previously broken package upgrade.
    elif [ -e %{_sysconfdir}/waagent.conf.rpmsave ]; then
        cp -Z %{_sysconfdir}/waagent.conf.rpmsave %{_sysconfdir}/waagent.conf
        #restart the waagent.service again the restert in post failed due
        # to missing config
        systemctl try-restart waagent.service
    fi
fi
%if 0%{?suse_version} > 1500
# Migration to /usr/etc, restore just created .rpmsave
for i in logrotate.d/waagent ; do
    test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%post
%service_add_post waagent.service

%preun
%service_del_preun waagent.service

%postun
%restart_on_update waagent
%service_del_postun waagent.service

%post config-default
rm -rf %{_sysconfdir}/waagent.conf
ln -s %{_sysconfdir}/waagent.conf.default %{_sysconfdir}/waagent.conf

%post config-server
rm -rf %{_sysconfdir}/waagent.conf
ln -s %{_sysconfdir}/waagent.conf.server %{_sysconfdir}/waagent.conf

%post config-hpc
rm -rf %{_sysconfdir}/waagent.conf
ln -s %{_sysconfdir}/waagent.conf.hpc %{_sysconfdir}/waagent.conf

%post config-micro
rm -rf %{_sysconfdir}/waagent.conf
ln -s %{_sysconfdir}/waagent.conf.micro %{_sysconfdir}/waagent.conf

%files
%defattr(0644,root,root,0755)
%doc NOTICE README.md
%license LICENSE.txt
%exclude %{_sysconfdir}/waagent.conf*
%{_sbindir}/rcwaagent
%attr(0755,root,root) %{_sbindir}/waagent
%if 0%{?suse_version} > 1500
%{_distconfdir}/logrotate.d/waagent
%else
%config(noreplace) %{_sysconfdir}/logrotate.d/waagent
%endif
%ghost %{_localstatedir}/log/waagent.log
%{_unitdir}/waagent.service
%{_prefix}/lib/udev/rules.d/66-azure-storage.rules
%{_prefix}/lib/udev/rules.d/99-azure-product-uuid.rules
%dir %{_sitelibdir}/azurelinuxagent
%{_sitelibdir}
%exclude %{_sitelibdir}/azurelinuxagent/tests
%if 0%{?suse_version} <= 1315
%attr(0755,root,root) %{_sbindir}/waagent2.0
%endif

%files test
%defattr(0644,root,root,0755)
%{_sitelibdir}/azurelinuxagent/tests

%files config-default
%ghost %{_sysconfdir}/waagent.conf
%config(noreplace) %{_sysconfdir}/waagent.conf.default

%files config-server
%ghost %{_sysconfdir}/waagent.conf
%config(noreplace) %{_sysconfdir}/waagent.conf.server

%files config-hpc
%ghost %{_sysconfdir}/waagent.conf
%config(noreplace) %{_sysconfdir}/waagent.conf.hpc

%files config-micro
%ghost %{_sysconfdir}/waagent.conf
%config(noreplace) %{_sysconfdir}/waagent.conf.micro

%changelog
* Mon Dec 23 2024 Robert Schweikert <rjschwei@suse.com>
- Update to version 2.12.04 (bsc#1235140)
  + Remove agent-no-auto-update.patch handeled by config file specialization
    sub-packages
  + Remove paa_force_py3_sle15.patch handled by RPM macro
  + Remove agent-micro-is-sles.patch included upstream
  + Forward port paa_12_sp5_rdma_no_ext_driver.patch
  + Forward port remove-mock.patch
  + Add paa_direct_exec_in_service.patch
    ~ The waagent script is executable and we set the proper interpreter
    using the macro for multibuild python. Do prefix the execution in the
    service file wit the interpreter
  + Fix install_requires list syntax
  + Update spec file
    ~ Remove conditions for distros no longer maintained
    ~ Simplify build and install conditionals using macros
  + Enable GA versioning #3082 #3184 #3189
  + Cgroups api refactor for v2 #3096 #3135 #3188 #3196
  + Fix JIT for FIPS 140-3 #3190
  + reset network service unit file if python version changes #3058
  + Recognize SLE-Micro as a SLE based distribution #3048
  + Add distutils/version.py to azurelinuxagent #3063
  + Use legacycrypt instead of crypt on Python >= 3.13 #3070
  + Fix osutil/default route_add to pass string array. #3072
  + Fix argument to GoalState.init #3073
  + Add lock around access to fast_track.json #3076
  + Add DistroVersion class to compare distro versions #3078
  + LogCollector should skip and log warning for files that don't exist #3098
  + check for unexpected process in agent cgroups before cgroups enabled #3103
  + [Redo with correct source/target]: Remove check for "ibXX" interface
    format and rework mac-address regex to expand support #3150
  + Fix Ubuntu version codename for 24.04 #3159
  + Update test certificate data #3166
  + move setupslice after cgroupsv2 check, remove unit file for
    log collector and remove fiirewall daemon-reload #3223
  + Address pylint warning deprecated-method #3059
  + Run pylint on Python 3.11 #3067
  + Run unit tests with pytest on Python >= 3.10
  + Log logcollector cgroups if process is found in unexpected slice #3107
  + remove secret and use cert for aad app in e2e pipeline #3116
  + suppress pylint warn contextmanager-generator-missing-cleanup #3138
  + Switching to SNI based authentication for aad app #3137
  + updated PR template #3144
  + Avoiding mocked exception from being lost on test when using
    python 3.12: complete mocked info #3149
  + Add more useful logging statement for agent unit properties #3154
  + Remove wireserver fallback for imds calls #3152
  + Remove unused import #3155
  + Add support for Azure Linux 3 #3183
  + Fix pytest warnings #3084
  + Allow use of node 16 #3160
  + Send controller/cgroup path telemetry #3231
  From 2.13.0.2
  + #3221 Add support for nftables (+ refactoring of firewall code)
  + #3239 Create walinuxagent nftable atomically
  + Features in progress (Verify extension signature/Policy Enforcement)
  + #3200 Parse encodedSignature property from EGS
  + #3187 Add Regorus policy engine framework
  + #3222 Remove Regorus and platform check for policy enforcement
  + #3242 Telemetry (update logcollector telemetry with common properties)
  + #3208 Handle non-boolean when parsing extension manifests
  + #3211 Fix unicode type check when parsing extension manifests
  + #3133 Telemetry: high-priority events
  + #3240 Telemetry: report apparent dead code
  + #3210 Cleanup: remove AMA extension services cgroups tracking code
  + #3197 Accommodate the new behavior in OpenSSL 3.2.2 when given an
    empty input
  From 2.11.1.12
  + Remove multi config extension status only on extension delete #3172
  From 2.111.1.4
  + General Improvements
  + Improvements in telemetry for firewall settings #3110, #3124
  From 2.10.0.8
  + GA versioning #2810 #2850 #2860 #2881 #2974 #3004 #3015 #3033
  + Disabled GA versioning #2909 #2917 #3044
  + Add regular expression to match logs from very old agents #2839
  + Remove empty "distro" module #2854
  + Enable Python 2.7 for unit tests #2856
  + Add check for noexec on Permission denied errors #2859
  + Reorganize file structure of unit tests #2894
  + Report useful message when extension processing is disabled #2895
  + Add log and telemetry event for extension disabled #2897
  + Cleanup common directory #2902
  + Fix agent memory usage check #2903
  + enable rhel/centos agent-cgroups #2922
  + Add support for EC certificates #2936
  + Add Cpu Arch in local logs and telemetry events #2938
  + Clarify support status of installing from source. #2941
  + Gathering Guest ProxyAgent Log Files #2975
  + Remove debug info from waagent.status.json #2971
  + Handle errors when adding logs to the archive #2982
  + Update supported Ubuntu versions #2980
  + Fix pylint warning #2988
  + Add information about HTTP proxies #2985
  + update the proxy agenet log folder for logcollector #3028
  + Add config parameter to wait for cloud-init
    (Extensions.WaitForCloudInit) #3031 [Added in 2.10.0.8]
  + Adding AutoUpdate.UpdateToLatestVersion new flag support #3020 #3027
    [Added in 2.10.0.8]
  + Check certificates only if certificates are included in goal state #2803
  + Redact access tokens from extension's output #2811
  + Fix name of single IB device when provisioning RDMA #2814
  + Port NSBSD system to the latest version of waagent #2828
  + fix daemon version #2874
  + fix version checking in setup.py #2920
  + fix(ubuntu): Point to correct dhcp lease files #2979
  + Download certs on FT GS after check_certificates only when missing
    from disk #2907
  + Add support for EC certificates (#2936) #2943 [Added in 2.10.0.5]
  + Fix for "local variable _COLLECT_NOEXEC_ERRORS referenced before
    assignment" (#2935) #2944 [Added in 2.10.0.5]
  + Cache daemon version #2942 #2946 [Added in 2.10.0.5]
  + undo get daemon version change #2951 [Added in 2.10.0.5]
  + fix self-update frequency to spread over 24 hrs for regular type
    and 4 hrs for hotfix #2948 [Added in 2.10.0.5]
  + ignore dependencies from extensions that do not have settings #2957
    [Added in 2.10.0.6]
  + Do not reset the mode of a extension's log directory #3014
    [Added in 2.10.0.8]
  + skip cgroup monitoring if log collector doesn't start by the agent.
    [#2939] [Added in 2.10.0.8]
  + NM should not be restarted during hostname publish if NM_CONTROLLED=y
    [#3008] [Added in 2.10.0.8]
  + Daemon should remove stale published_hostname file and log
    useful warning #3016 [Added in 2.10.0.8]
  + Revert changes to publish_hostname in RedhatOSModernUtil #3032
    [Added in 2.10.0.8]
  + Recover primary nic if down after publishing hostname in
    RedhatOSUtil #3024 [Added in 2.10.0.8]
* Thu Oct 31 2024 Dirk Müller <dmueller@suse.com>
- fix a few typos in the spec file and use proper macros where
  applicable
- remove python3 requires
* Mon Aug 19 2024 Robert Schweikert <rjschwei@suse.com>
- Restart the agent (bsc#1227600)
  + The agent service gets restarted in post but may fail due to a missing
    config file. config files were split into their own package previously.
    When we detect that we have to restore a config file we also need
    to restart the agent again.
* Fri Jul 12 2024 Robert Schweikert <rjschwei@suse.com>
- Add agent-btrfs-use-f.patch (bsc#1227711)
  + Use the proper option to force btrfs to overwrite a file system on the
    resource disk if one already exists.
* Wed Jul 10 2024 Joachim Gleissner <jgleissner@suse.com>
- Set Provisioning.Agent parameter to 'cloud-init' in SLE Micro >= 5.5
  (bsc#1227106).
- Do not package waagent2.0 in Python 3 builds.
- Drop obsolete otherproviders keyword from Conflicts statements
* Mon Jul  1 2024 Joachim Gleissner <jgleissner@suse.com>
- Do not require wicked in non-SUSE build environments.
* Wed Jun 26 2024 Joachim Gleissner <jgleissner@suse.com>
- Apply python3 interpreter patch in non SLE build environments
  (bcs#1227067)
- Simplify %%suse_version conditionals
* Wed Jun  5 2024 Robert Schweikert <rjschwei@suse.com>
- Use the -Z option for mv and cp in the posttrans to properly handle
  SELinux context (bsc#1225946)
* Wed Apr 10 2024 Robert Schweikert <rjschwei@suse.com>
- Keep the existing config file (bsc#1222620)
  + During separation of the config file into subpackages it was forgotten
    that on update of the main package the previously provided config file
    would be removed. SInce we do not know which flavor of our images the
    package is being upgraded on, preserve the previously existing config
    file. This will orphan the file if non of the -config-* packages gets
    installed.
* Tue Feb 20 2024 Robert Schweikert <rjschwei@suse.com>
- Do not force wicked dependency for networking, allow NM in SLE Micro 5.5
  and for ALP based products
- Change patch syntax in preparetion for RPM 4.20
* Mon Feb 12 2024 Robert Schweikert <rjschwei@suse.com>
- Recognise SLE-Micro as a SLE based distro
  + Add agent-micro-is-sles.patch
* Mon Nov 13 2023 Robert Schweikert <rjschwei@suse.com>
- Create sub-packages for the config (jsc#PED-7869)
  + Remove config manipulation from image building
  + Set up a config for SLE-Micro
  + Makes deafult upstream config available
- Update to 2.9.1.1 (bsc#1217301, bsc#1217302)
  + Update remove-mock.patch
  + Download certificates when goal state source is fast track #2761
  + Increase the max number of extension events by 20%% #2785
  + Remove version suffix from extension slice #2782
  + Support int type for eventPid and eventTid fields #2786
  + Improve log for swap counter not found #2789
  + Remove cgroup files during deprovisioning #2790
  + Log VM architecture in heartbeat telemetry for arm64 adoption
    monitoring #2818
  + Enforce memory usage for agent #2671
  + Use common download logic for agent downloads #2682
  + Implement Fedora distro #2642
  + Report message in handler heartbeat #2688
  + Remove dependency on pathlib from makepkg #2717
  + Do not fetch extensions goal state in log collector #2713
  + Update log collector unit file to remove memory limit #2757
  + Fix bug in get_dhcp_pid (CoreOS) #2784
  + Fetch full distro version for mariner #2773
  From 2.9.04
  + Resource Governance on extensions (CPU monitoring and enforcing & Memory
    monitoring) #2632 #2581 #2555
  + Agent resource governance #2597 #2591 #2546
  + monitor system-wide memory metrics (#2610)
  + Additional telemetry for goal state (#2675)
  + HostGAPlugin usage improvements #2662 #2673 #2655 #2651
  + Add logging statements for mrseq migration during update (#2667)
  + Logcollector memory usage #2658 #2637
  + Update Log Collector default in Comments and Readme (#2608)
  + Improve telemetry success and failure markers (#2605) #2604 #2599
  + Fix formatting of exceptions on Python 3.10
    (traceback.format's etype argument) (#2663)
  + Fix UNKNOWN(Zombie) Process in unexpected processes check (#2644)
  + SUSE: Fix valid values for DHCLIENT_HOSTNAME_OPTION (#2643)
  + Debian - string conversion for systemd service (#2574)
  + Do not set a CPU quota on the agent for RHEL and Centos (#2685) #2689 #2693
  + support rhel distro (#2620) #2598
  + Added support for devuan linux distribution (#2553)
  No incremental updates between 2.8.011 and 2.9.0.4
* Thu Feb  9 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Clean up conditions in spec file:
  + There is no maintained distro > 1315 (SLE12) AND < 1500
    (SLE15). Only openSUSE 13.2 and 13.3 lived in that space, but
    they are clearly not the target of this spec file.
  + if 0%%{?Suse_version} && 0{?suse_version} > 1315: no need to
    first validate suse_version being defined: whenever it
    is > 1315, must be defined.
* Wed Jan 25 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-mock.patch:
  * Use unittest.mock first, falling back to mock if required.
- Tighten Requires against python3-mock.
* Thu Sep 29 2022 Robert Schweikert <rjschwei@suse.com>
- Add paa_12_sp5_rdma_no_ext_driver.patch (bsc#1203181)
* Thu Sep 29 2022 Robert Schweikert <rjschwei@suse.com>
- Update to version 2.8.0.11 (bsc#1203164)
  + Enabled support for Fast Track (faster processing of extensions)
  + Add telemetry for VM Size
  + Add telemetry for environment variables passed to extensions
  + Enforce CPU quota on the Agent on Red Hat and CentOS 7.4+
  + Restore all firewall rules needed for communication with the WireServer
  + Fix false positives reporting processes in the Agent's cgroup
  + Fix false errors when collecting debug logs
  + Don't report incorrect CPU usage data
  + Fetching a goal state with empty certificates property
  + Silence goal state fetch errors after 3 logs
  + Change fast track timestamp default from None to datetime.min
  + Retry HGAP's extensionsArtifact requests on BAD_REQUEST status
  + Support for Rocky Linux
  + RHEL 8
  + RHEL 9
  + Preliminary work to enforce CPU quota on extensions
  + Preliminary work for management of agent self-updates [GA Versioning]
  + Add CentOS 7.9 to end-to-end-tests
  + Add Mariner to end-to-end-tests
- 2.8.0.11 followed 2.7.3.0, no intermediate releases
* Thu Sep  1 2022 Stefan Schubert <schubi@suse.com>
- Migration to /usr/etc: Saving user changed configuration files
  in /etc and restoring them while an RPM update.
* Thu Aug 11 2022 Robert Schweikert <rjschwei@suse.com>
- Update to 2.7.3.0 (jsc#PED-1298)
  + Remove proper_dhcp_config_set.patch included upstream
  + Remove sle_hpc-is-sles.patch included upstream
  + Forward port reset-dhcp-deprovision.patch
  + Retry HGAP's extensionsArtifact requests on BAD_REQUEST status #2622
  + Use 'ip' instead of 'ifdown/ifup' to restart network interface on
    RHEL >= 8.6 #2612 #2624
- From 2.7.1.0
  + hotfix for OOM errors on the log collector
- From 2.7.0.6
  + Increase time of autoupdates after updates are available #2403
  + Send telemetry when upgrade available #2421
  + Enable collection of debugging information #2436, #2453, #2510
  + Add support for Python 2.6 to the debug info collection code #2452
  + Enable CPU/memory data collection on RedHat and CentOS #2450
  + Exclude end-to-end tests from Agent setup #2396, #2402
  + Fix log message in cgroups management #2427
  + Fix parsing of malformed error.json files #2433
  + Allow DNS queries over TCP #2429
  + Dont exit extension handler process if unable to fetch
    first goal state #2440
  + Improvements for Mariner #2407, #2414
  + Add uos support #2420
  + Add support for VMware PhotonOS #2431
- From 2.6.0.2
  + added cloudlinux support (#2344)
  + Enable extensions cpu monitoring (#2357, #2384, #2391)
  + Support Flatcar Container Linux (#2365)
  + Retrieve VmSettings from HostGAPlugin
    (#2378, #2382, #2386, #2394, #2397, #2404)
  + Set Agent's CpuQuota to 75%% (#2383)
  + Use handler status if extension status is None when computing
    the ExtensionsSummary (#2358) (#2361)
  + fix bug with dependent extensions with no settings (#2285) (#2362)
  + Create events dir for handlers if ETP enabled (#2366)
  + Report status even if goal state cannot be processed (#2370)
  + Define ExtensionsSummary.eq (#2371) (#2373)
  + Implement ExtensionsSummary.ne in terms of eq (#2375)
- From 2.5.0.2
  + Enable Extension Telemetry Pipeline (#2337, #2339)
  + Enable Periodic Log Collection in systemd distros (#2295,#2289)
  + Implement InitialGoalStatePeriod parameter + improvements in logging
    goal state processing(#2332)
  + Fix operation name in InitializeHostPlugin event(#2338)
  + Mock systemctl stop cmd (#2335)
  + Report transitioning when status file not found (#2330)
  + Dont create default status file for Single-Config extensions (#2318)
  + Do not create placeholder status file for AKS extensions (#2298)
  + Save waagent_status to history folder and add additional details to
    the status file (#2325,#2301,#2270)
  + Rename Debug.FetchVmSettings to Debug.EnableFastTrack (#2324)
  + Update HostGAplugin headers before fetching vmSettings (#2323)
  + Handle HTTP GONE in vmSettings request (#2321)
  + Added log statements to debug issues in vmSettings API(#2317)
  + Remove reference to re.IGNORECASE (#2316)
  + Add and remove extension slice (#2315)
  + FastTrack changes (#2314, #2313,#2306, #2304,#2294, #2293)
  + Helper to handle exception message(#2305)
  + Remove trailing spaces from command name (#2296)
  + Add debug info for systemd-run false positives (#2292)
  + Move Github Actions VMs to Ubuntu 18 (#2291)
  + Onboard redhat82, ubuntu20 (#2290, #2279)
  + Allow systemd-run in the Agent's cgroup (#2287)
  + Use handler status if extension status is None (#2358)
  + Bug Fix :Define ExtensionsSummary.ne (#2371)
- From 2.4.0.2
  + Support for Multi config (#2245, #2261)
  + Support sles 15 sp2 distro (#2272)
  + Cleanup history folder every 30 min (#2258)
  + Updated _read_status_file to include a fragment of status file in
    the exception (#2257)
  + Fix telemetry unicode errors (Re-add #1937) (#2278)
  + Match IPoIB interface with any alphanumeric characters (#2239)
  + Fix bug with dependent extensions with no settings (#2285)
  + Do not create placeholder status file for AKS extensions (#2298)
  + Refactoring of Agent's main loop (#2275)
  + Exception for Linux Patch Extension for creating placeholder
    status file (#2307)
  + Dont create default status file for Single-Config extensions (#2318)
  + Fix bad logging (#2241)
  + Fixed logging of PeriodicOperation (#2263)
  + Log collector broken pipe fix (#2267)
  + Improved logging for Multi config (#2246)
- From 2.3.1.1
  + revert for reducing the time window where we restart the network
    interfaces of the VM
- From 2.3.0.2
  + Enforce CPUQuota on agent #2222, #2226
  + Add support for RequiredFeatures and GoalStateAggregateStatus APIs
    [#2190], #2206, #2209, #2216
  + Added fallback locations for extension manifests #2188
  + Add missing call to str.format() when creating exception #2193
  + Remove helper network service on deprovision #2191
  + Use a helper script to start the network service #2225 #2253
  + Initialize published_hostname using /var/lib/cloud/data/set-hostname #2215
  + Fix utf logging for persist firewall rules #2237
  + Replace firewall-setup unit file if changed #2236
- From 2.2.54
  + PA changes to check cloud-init (#2061)
  + log collector (#2066)
  + cgroups CPU percentage py processor count (#2074)
  + Parse InVMGoalStateMetaData from Extension Config (#2081)
  + iscsi disk support for agent configs (#2073)
  + Add support for VMs with multiple IB devices (#2085)
  + Python 3.9 support (#2082)
  + Add support for CBL-Mariner distro (#2099)
  + Enable Provisioning.MonitorHostName for Ubuntu (#1934)
  + Added supportedFeatures flag in status reporting (#2089)
  + Parse ext runtime settings (#2087)
  + GHA merge validation (#2097)
  + Cgroups improvements
  + renamed the eventsFolder variable for preview and enabled ETP (#2140)
  + Agent slice and custom unit files telemetry (#2150)
  + Make IPoIB interface online (#2116)
  + Add option to disable NetworkConfigurationChanges (#2156)
  + Log network configuration on service start (#2157)
  + Setup persistent firewall rules on service restart (#2154)
  + switched to using run_command (#2060)
  + fixes for chained-comparison and dangerous-default-value pylint
    warnings (#2072)
  + fixed depends on errors (#2059)
  + WireIp env variable added (#2078)
  + Unstick HGAP channel as default (#2046)
  + shellutil.run_command fixes (#2086, #2098)
  + unit test fixes (#2090, #2091, #2108, #2153)
  + fix distro resolution for RedHat (#2083)
  + Read KVP value in binary mode (#2084)
  + Redact protected settings in goal state debug files (#2130)
  + Modify retry logic for empty goal state (#2140)
  + GS no config fix (#2141)
  + CommandExecution.log logrototate config -> custom log management (#2143)
  + binary file for firewall rules (#2147)
  + Refresh host ga plugin periodically (#2155)
  + Disabled custom service (#2166)
  + update test zips (#2167)
- From 2.2.53.1
  + Extension Telemetry Pipeline as a private-preview feature
- From 2.2.53
  + Start exthandler with the same python interpreter (#2007)
  + Verify that the extension status is an array (#2010)
  + Remove enum _UpdateType and retry fetching goal state (#2018)
  + use dd for ext4 as well as xfs (#2042)
  + Fix path for error.json (#2044)
  + Switch to run command changes, + provisioning changes that need to be
    reverted. (#2050)
  + Fix timestamp for goal state archive (#2051)
  + Case insensitive parsing or Plugins and PluginSettings (#2054)
  + Revert "Fixed delays for HTTP retries rather than exponential
    delays (#1967)" (#2065)
  + Fixed bug causing "MAC verified OK" message (#2069)
  + Revert unicode fix manually (#1937) (#2070)
  + Recreate handler environment file on service startup (#1960)
  + Add log collection tool and thread (#1987)
  + Thread interface (#1990)
  + Verify that the CPU and Memory cgroups for the agent are properly
    initialized; disabled cgroups if they are not active. (#2015)
  + SUSE config: use Btrfs LZO compression for ResourceDisk (#2055)
  + Extension telemetry pipeline (#1918)
  + Reformatted the heartbeat event (#2009)
  + Add LIS version to OSInfo.message (#2011)
  + One thread for telemetry (#2019)
  + Limit description character length sent for health report (#2020)
  + Remove Serial Console Logging (#2028)
  + Echo log to /dev/console during provisioning (#2043)
  + Adding telemetry for logrotate (#2045)
  + Report placeholder extension status as an array (#2068)
  + Fix broken link in readme (#2014)
  + Add log collector flags to README (#2029)
- From 2.2.52
  + Do not retrieve users in each goal state (#1935)
  + Fix check for systemd-run failure when invoking extensions (#1943)
  + Fix telemetry unicode errors (#1937)
  + Uninstall unregistered extensions (#1970)
  + Use run_command to execute iptables (#1944)
  + Use run_command for ip route (#1958)
  + Fix handling of gen2 disks with udev rules (#1954)
  + Add API for uploading logs via host plugin (#1902)
  + Fixed delays for HTTP retries rather than exponential delays (#1967)
  + Resolve undefined variable (#1950)
  + Convert owner uid to string (#1949)
  + Fix Travis special checks for distro and remove useless cgroup tests (#1959)
  + Use tmp_dir instead of data_dir (#1968)
* Tue Jun 21 2022 Stefan Schubert <schubi@suse.com>
- Removed %%config flag for files in /usr directory.
* Mon Jun 20 2022 Stefan Schubert <schubi@suse.com>
- Cleanup spec file:
  - - Removed %%{_distconfdir}/logrotate.d from dirlist. It will be
    handled by package filelist now.
  - - %%{_distconfdir}/logrotate.d/* can be changed by vendor only.
    So it will be replaced by an RPM update.
* Wed Jun 15 2022 Stefan Schubert <schubi@suse.com>
- Moved logrotate files from user specific directory /etc/logrotate.d
  to vendor specific directory /usr/etc/logrotate.d.
* Tue May 17 2022 pgajdos@suse.com
- require python-rpm-macros to fix build for TW
- do not require test dependencies for build, they are not needed
  (no testsuite run in %%check)
* Thu May  5 2022 Robert Schweikert <rjschwei@suse.com>
- Add reset-dhcp-deprovision.patch (bsc#1198258)
  + Reset the dhcp config when deprovisioning and instance to ensure
    instances from aVM image created from that instance send host information
    to the DHCP server.
* Sat Jan 30 2021 Robert Schweikert <rjschwei@suse.com>
- Add sysvinit-tools as dependency (bsc#1181600, bsc#1181601)
* Tue Jan 12 2021 Robert Schweikert <rjschwei@suse.com>
- Add sle_hpc-is-sles.patch (bsc#1180719)
  + Recognise SLE_HPC as SLES and use the proper RDMA handler and
    distro specific initialization code
* Sat Oct  3 2020 Robert Schweikert <rjschwei@suse.com>
- Update proper_dhcp_config_set.patch (bsc#1177161, bsc#1177257)
  + Add missing imports
* Thu Sep 10 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 2.2.49.2 (bsc#1176368, bsc#1176369)
  + Remove paa_use_hostnamectl.patch included upstream
  + Forwrad port proper_dhcp_config_set.patch
  + Do not use --unit with systemd-cgls (#1910)
  + Report processes that do not belong to the agent's cgroup (#1908)
  + Use controller mount point for extension cgroup path (#1899)
  + Improvements in setup of cgroups (#1896)
  + Remove ExtensionsMetricsData and per-process Memory data (#1884)
  + Fix return value of start_extension_command (#1927)
  + Remove import * (#1900)
  + Fix flaky ExtensionCleanupTest class (#1898)
  + Fix codecov badge (#1883)
  + Changed codecov to run on py3.8 (#1875)
  + Update documentation on /dev/random (#1909)
  + Mount options are in mount(8) (#1893)
  + Remove ssh host key thumbprint in report ready (#1913)
  + Emit AutoUpdate value at service start only (#1907)
  + Add logging for version mismatch (#1895)
  + Send telemetry event if libdir changes (#1897)
  + Add log collector utility (#1847)
  + Move AutoUpdate reporting to HeartBeat event (#1919)
  + Removing infinite download of extension manifest without a new GS (#1874)
  + Fix wrongful dir deletion (#1873)
  + Fix the cleanup-outdated-handlers to only delete handlers that are not
    present in the GS (#1889)
  + Expose periods of environment thread in waagent.conf (#1891)
  + Added user @kevinclark19a as Contributor. (#1906)
- From 2.2.48.1
  + Refactoring GoalState class out of Protocol, making Protocol thread-safe,
    removing stale dependencies of Protocol and removing the dependency on
    the file system to read the Protocol info
  + Fetch goal state when creating HostPluginProtocol (#1799)
  + Separate goal state from the protocol class (#1777)
  + Make protocol util a singleton per thread (#1743, #1756)
  + Fetch goal state before sending telemetry (#1751)
  + Remove file dependency (#1754)
  + Others (#1758, #1767, #1744, #1749, #1816, #1820)
  + New logs for goal state fetch (#1797) and refresh (#1794).
  + Thread name added to logs (#1778)
  + Populate telemetry events at creation time (#1791)
  + Periodic HeartBeat to be logged to the file (#1755)
  + Add unit test to verify call stacks on telemetry events (#1828)
  + Others (#1841, #1842, #1846)
  + Handling errors while reading extension status files
    (Limiting Size and Transient issues)(#1761)
  + Enable SWAP on Resource Disk as Application Certification Support
    suggested (#1762)
  + Update 'Provisioning' options in default configs ( #1853)
  + Drop Metadata Server Support (#1806, #1839, #1840 )
  + Improve documentation of ResourceDisk.EnableSwapEncryption (#1782)
  + Removed is_snappy function (#1774)
  + Handle exceptions in monitor thread (#1770)
  + Fix timestamp for periodic operations in the monitor thread (#1879)
  + Fix permissions on the Ubuntu systemd service file (#1814)
  + Update hostname setting for SUSE distros (#1832)
  + Python 3.8 improvements + support for Ubuntu 20.04 (#1860, #1865, #1738)
  + Testing and dev-infra improvements
    [#1771, #1768, #1800, #1826, #1827, #1833]
  + Others (#1854, #1858)
- From 2.2.46
  + [#1741] Do not update goal state when refreshing the host plugin
  + [#1731] Fix upgrade sequence when update command fails
  + [#1725] Initialize CPU usage
  + [#1716, #1737] Added UTC logging and correcting the format
  + [#1651, #1729] Start sending PerformanceCounter metrics and
    additional memory information for Cgroups
* Fri Aug 14 2020 Robert Schweikert <rjschwei@suse.com>
- Drop paa_sudo_sle15_nopwd.patch (bsc#1175198)
  + sudoers file is managed by cloud-init we no longer need this hack
* Fri Jul 17 2020 Robert Schweikert <rjschwei@suse.com>
- Add proper_dhcp_config_set.patch (bsc#1173866)
  + Properly set the dhcp configuration to push the hostname to the DHCP
    server
  + Do not bring the interface down to push the hostname, just use ifup
* Tue Mar 24 2020 Robert Schweikert <rjschwei@suse.com>
- Add paa_use_hostnamectl.patch (bsc#1167601, bsc#1167602)
  + Set the hostname using hostnamectl to ensure setting is
    properly applied
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through -mini flavors.
* Thu Dec  5 2019 Robert Schweikert <rjschwei@suse.com>
- Update to version 2.2.45 (jsc#ECO-80)
  + Remove paa_cve_2019-0804.patch, included upstream
  + Add support for Gen2 VM resource disks
  + Use alternate systemd detection
  + Fix /proc/net/route requirement that causes errors on FreeBSD
  + Add cloud-init auto-detect to prevent multiple provisioning mechanisms
    from relying on configuration for coordination
  + Disable cgroups when daemon is setup incorrectly
  + Remove upgrade extension loop for the same goal state
  + Add container id for extension telemetry events
  + Be more exact when detecting IMDS service health
  + Changing add_event to start sending missing fields
- From 2.2.44
  + Remove outdated extension ZIP packages
  + Improved error handling when starting extensions using systemd
  + Reduce provisioning time of some custom images
  + Improve the handling of extension download errors
  + New API for extension authors to handle errors during extension update
  + Fix handling of errors in calls to openssl
  + Improve logic to determine current distro
  + Reduce verbosity of several logging statements
- From 2.2.42
  + Poll for artifact blob, addresses goal state procesing issue
- From 2.2.41
  + Rewriting the mechanism to start the extension using systemd-run for
    systems using systemd for managing
  + Refactoring of resource monitoring framework using cgroup for both
    systemd and non-systemd approaches [#1530, #1534]
  + Telemetry pipeline for resource monitoring data
- From 2.2.40
  + Fixed tracking of memory/cpu usage
  + Do not prevent extensions from running if setting up cgroups fails
  + Enable systemd-aware deprovisioning on all versions >= 18.04
  + Add systemd support for Debian Jessie, Stretch, and Buster
  + Support for Linux Openwrt
- From 2.2.38
  + Fix CVE-2019-0804
  + Add fixes for handling swap file and other nit fixes
- From 2.2.37
  + Improves re-try logic to handle errors while downloading extensions
* Thu Mar  7 2019 Robert Schweikert <rjschwei@suse.com>
- Add paa_cve_2019-0804.patch (bsc#1127838)
  - An issue with swapfile handling in the agent creates a data leak situation
    that exposes system memory data.
* Thu Feb  7 2019 Robert Schweikert <rjschwei@suse.com>
- Update to 2.2.36 (bsc#1119542)
  - Remove, included upstream
    + paa_fix_driver_install_detect.patch
    + paa_rdma_install_proper_driver.patch
    + 0001-Obtain-platform-information-in-Python-version-depend.patch
    + 0001-Detect-openSUSE-and-SLES.patch
    + 0001-Handle-the-disapperance-of-net-tools.patch
    + 0001-Properly-detect-SLES-15-for-rdma-support.patch
  - Forward port agent-no-auto-update.patch
  - [#1451] Do not utf-8 encode telemetry messages
- From 2.2.35
  + [#1434] Use files instead of pipes to capture stdout/stderr
  + [#1431] Prevent multiple downloads of zips
  + [#1418] Add main module to Python's egg
  + [#1416] Fix UTF-8 encoding for telemetry payload
  + [#1408] Honor the 'no_proxy' flag
  + [#1391, #1401, #1441] Azure Stack improvements
  + [#1384] Write status file in WALinuxAgent lib folder
  + [#1375] Add support for Redhat
  + [#1373] Handle different kernel builds on SUSE Linux Enterprise
  + [#1365, #1385, #1389] Fixes for RDMA
- From 2.2.34
  + [#1397] Send events when extensions fail to complete operation
  + [#1394/#1366] Fix the threshold telemetry issue
  + [#1298] Implementing extension sequencing in azure Linux agent
  + [#1340] Allow Clear Linux detection in python2 and python3
  + [#1345] FreeBSD swap issues fix (#1144)
  + [#1349] Use append_file in Redhat6xOSUtil.openssl_to_openssh()
  + [#1355] Ensure 'value' for authorized ssh keys end in "\n"
  + [#1361] Remove main module
- From 2.2.32
  + [#1325] Enable cgroups by default on all distros
  + [#1327, #1347] Allow enforcing of cgroups limits
  + [#1337] Allow configuration for cgroups
  + [#1333] Add support for NSBSD
  + [#1319] Stream extension downloads to disk
    (do not buffer the download in memory)
  + [#1303] Fix to support custom DNS servers
  + [#1306] Log extension stdout and stderr
  + [#1302] Better of cloud-init configuration during deprovisioning
  + [#1295] Fix to report the correct extension error code
  + [#1289] Allow disabling the agent or extensions
  + [#1290] Use the "ip route" command instead of the "route" comand
    during network configuration
  + [#1281] Delete JIT accounts
  + [#1234] Fix for reading KVP values from host
  + [#1287] Add UDEV rule in azure disk encryption
- From 2.2.31
  Upstream version jump
  + [#1196] Health store integration
  + [#1199] CGroups support
  + [#1194] Use host for status reporting
  + [#1188] Fix for sentinel and signal handlers
  + [#1182] Telemetry updates
  + [#1171] Add support for JIT
  + [#1164] Fix for name resolution in Ubuntu 18.04
  + [#1154] Set connection close header
  + [#1143] Remove extension packages after extraction
- From 2.2.26
  + Update Debian specific configuration and setup.
- From 2.2.25
  + Upstream version jump
  + Revert extension manifest caching to prevent downgrade issues.
- From 2.2.20
  + This is a hotfix release for #945, details and mitigation are available
    in the wiki.
- From 2.2.29
  + [#929] wire.py#update_goal_state does not handle out-of-date
    GoalState errors
  + [#908] Set Files to 0400 in /var/lib/waagent
  + [#906] Hardcoded value for sshd's ClientAliveInterval (180)
  + [#899] Improve HeartBeat Event
  + [#898] Send dummy status if extension fails to write a #.status file
  + [#897] 'Target handler state' wall of errors
  + [#896] End of Line Comments are Not Supported nor Handled
  + [#891] Create a Telemetry Event to Track Custom Data Execution
  + [#884] Cleanup Old Goal State and Extension Cache
  + [#876] The agent should use a scaling back-off when retrying HTTP requests
  + [#869] The agent should report OS information in the correct JSON format.
  + [#822] Update docs
* Wed Jun  6 2018 rjschwei@suse.com
- Remove paa_up_only_to_push_hostname.patch
  + Turns out the issue was a kernel bug and while ifdown ifup sequence to
    bounce the hostname to the DHCP server is overkill we do not
    want to carry a "cosmetic" patch
* Tue Jun  5 2018 rjschwei@suse.com
- Add paa_up_only_to_push_hostname.patch (bsc#1094420)
* Thu May 10 2018 rjschwei@suse.com
- Add 0001-Handle-the-disapperance-of-net-tools.patch (bsc#1092831)
  + Switch to using "ip route" command
- Add paa_sudo_sle15_nopwd.patch
  + Work around issue where SLE 15 will not accept the user password when
    using sudo, cause unknown, needed to time constraints w.r.t. release
- Add 0001-Properly-detect-SLES-15-for-rdma-support.patch
  + Properly detect SLES 15 for RDMA support
* Mon Apr  2 2018 rjschwei@suse.com
- Add 0001-Detect-openSUSE-and-SLES.patch (bsc#1087764)
  + Properly detect SLES 15 and openSUSE Leap 15 in Python 3
* Tue Mar 20 2018 rjschwei@suse.com
- Update paa_force_py3_sle15.patch (bsc#1061584)
  + Another reference to python, which points to python2
* Tue Feb 27 2018 rjschwei@suse.com
- Add paa_force_py3_sle15.patch
  + Force use of Python 3 for SLE 15 and later
* Wed Feb 21 2018 rjschwei@suse.com
- Modify 0001-Obtain-platform-information-in-Python-version-depend.patch to
  reflect agreed upon solution with upstream
* Thu Feb  8 2018 rjschwei@suse.com
- Add 0001-Obtain-platform-information-in-Python-version-depend.patch
  to fix build on distribution with Python 3.6 and later (boo#997614)
* Fri Jan  5 2018 rjschwei@suse.com
- Fix RDMA driver package version install issue (bsc#1074865)
  + Added paa_rdma_install_proper_driver.patch
* Thu Oct 12 2017 rjschwei@suse.com
- Update to version 2.2.18
  + [#868] Fix for sudoer update
  + [#886] Agent should not update outside of goal state
  + [#889] Firewall removal should not retry
  - Fixes issues introduces with 2.2.17
* Tue Oct  3 2017 dimstar@opensuse.org
- BuildRequire distribution-release instead of
  openSUSE/sles-release.
* Wed Sep 20 2017 rjschwei@suse.com
- Fix typo in dependency
* Sat Sep 16 2017 rjschwei@suse.com
- Update to version 2.2.17 (bsc#1058974, bsc#1058975)
  + Remove paa_noref_local_install.patch, included upstream
  + Setup build for Python 3 for distros > SLE 12
  + [#879] -- OS.EnableFirewall=y breaks load balanced sets probing
- From 2.2.16
  + [#865] -- The agent should retry ETIMEDOUT (110) IOErrors
- From 2.2.15
  + [#783] -- The agent fails to use the standard Linux environment variables
    for HTTP proxy
  + [#784] -- Adjust http retry and logging
  + [#786] -- Add Provisioning.SshHostKeyPairType=auto to support ssh-keygen -A
  + [#791] -- Prevent bloating sudoers waagent when agent has problem
  + [#792] -- Clearlinux distro_name does not match
  + [#796] -- Accommodate new Clear Linux distro string in os-release
  + [#798] -- Support Ubuntu RDMA driver update
  + [#800] -- HostGAPlugin still use proxy while auto-updating
  + [#801] -- Agent fails to clean-up PID files
  + [#807] -- The agent should not emit duplicate events
  + [#808] -- The agent should more gracefully handle out-of-space disk
    errors (IOError 28)
  + [#811] -- Comments inline in /etc/waagent.conf cause config to not be read
  + [#812] -- Agent fails and isn't recoverable if an extension's log
    directory is not present anymore
  + [#823] -- Show config options in use
  + [#830] -- Ensure VM identifier is properly ordered
  + [#845] -- ')' is missed in show-configuration
  + [#850] -- Cannot get to state 'Running' with Provisioning.Enabled=n
* Fri Sep  8 2017 rjschwei@suse.com
- Add paa_fix_driver_install_detect.patch (bsc#1057888)
  + Avoid the driver from re-installing if the same version is already
    installed, this avoids an enless reboot loop
* Mon Jul 24 2017 rjschwei@suse.com
- Add paa_noref_local_install.patch (bsc#1050229)
  + Do not refresh the repos when we install the local RDMA kmp,
    repo access has already failed, no need to try again
* Sun Jul 23 2017 rjschwei@suse.com
- Update to version 2.2.14 (bsc#1050000)
  + [#777] -- Deprovisioning when VM identifier changes is too aggressive
  + [#769] -- HostGAPlugin requests should never go through proxy
  + [#764] -- waagent -configuration-path:/path -start not take effect
  + [#761] -- MetadataProtocol has no client object
  + [#757] -- deprovision is executed even if input 'n'
  + [#754] -- /etc/resolv.conf is removed if create a VM base on
    an specialized image
  + [#746] -- Agent WALinuxAgent-2.2.12 is blacklisted - skipping download
  + [#740] -- Duplicate logging on RHEL/CentOS
* Sun Jul 23 2017 rjschwei@suse.com
- Remove timeout udev rules (bsc#1049480)
  + 99-azure-timeout.rules
  + Rule is broken
  + Timeout is being set by the eagent code
* Tue Jun 13 2017 rjschwei@suse.com
- Modify dependencies, systemd is runtime, not build
* Thu Jun  8 2017 rjschwei@suse.com
- Update to version 2.2.13 (bsc#1042202, bsc#1042203)
  + [#712] Initial support for OpenBSD
  + [#730] Archlinux documentation
  + [#743] Fix for FreeBSD resource disk discovery
  + [#748] Fix for host plugin response encoding
  + [#750] Fix for GAiA public key handling
  + [#751] Fix for host plugin channel initialization
  + [#752] Fix for AzureStack protocol error handling
  + [#753] Removal of iptables rules from AzureStack protocol
- From 2.2.12
  + [#711] -- There are too many log print to /var/log/waagent.log
  + [#714] -- Questionable split call in common/conf.py
  + [#717] -- Remove extension logs during deprovision
  + [#720] -- Reset of RDMA drivers not taking effect
  + [#721] -- WALA deprovision process not clean up all cloudinit files
  + [#724] -- Location of configuration file should be editable issue
  + [#725] -- v2.2.11 can throw unexpected exceptions on provisioned VMs
  + [#727] -- v2.2.11 cannot update status for RDFE VMs
- From 2.2.11
  + [#463] Ensure the transport certificate expires in no more than two
    years enhancement
  + [#470] Emit goal state processing performance metrics enhancement
  + [#518] Align with the Azure Stack protocol enhancement
  + [#531] Location of configuration file should be editable feature request
  + [#604] v2.2.x - Need new OS.SshDir in waagent.conf feature request
  + [#631] Will "waagent -deprovision[+user]" wipe the cloud-init data?
    feature request
  + [#668] Agent continuously logs error on FIPS compliant server
  + [#679] Enable auto-update for AzureStack feature request
  + [#682] Default route is not added if it already exists cla-not-required
  + [#684] mkfs options out of order
  + [#685] Change option order for mkfs. Alpine is being picky
  + [#686] Use of hostnameclt causes hostname rename lowercase for RHEL 7.x
  + [#687] Enable customer-supported cloud-init
  + [#688] Agent should purge /var/lib/waagent/events if it gets full
  + [#689] Remove superseded extension folders / zip files
  + [#693] Agent should remove unused extension directories and zip
    files enhancement
  + [#694] Agent should not issue an HTTP HEAD to determine status blob
    type enhancement
  + [#695] Ensure all udev rules are copied in Ubuntu cla-not-required
  + [#699] [2.2.10] Some questions about Extension clean up
  + [#701] Reduce polling time for extension processing
  + [#706] Provision Event is not Fired if Customer Forgets to Deprovision VM
* Fri Apr 21 2017 rjschwei@suse.com
- Update to version 2.2.10 (bsc#1035418, bsc#1035419)
  + [#675] Clean up extension directories
  + [#673] Provisioning logging improvements
  + [#674] Override decode custom data
  + [#670] Add Arch distro support
- From version 2.2.9
  + [#665] Networking logging cleanup
  + [#666] Keygen logging cleanup
  + [#667] Reduce the monitoring loop wait time
- From version 2.2.8
  + [#649] Improve host plugin failure handling
  + [#647] Add telemetry for put status failures
  + [#646] Improve extension handler logging
  + [#645] Reduce guest agent update logging
  + [#644] Add basic 32-bit support to interface detection
  + [#641] Better heartbeat exception handling
  + [#640] Better unhandled exception logging
  + [#638] Improve NSG state management
  + [#637] Better handling and cleanup of old events
  + [#635] Pass environment variables to subprocess
  + [#634] Improve RDMA package matching
  + [#629] Better handling of resource disk mounting
  + [#624] Data disks udev rule
  + [#614] Add support for EulerOS
- From version 2.2.7
  + [#625] Enabled PageBlob support through HostGAPlugin
* Mon Mar 13 2017 rjschwei@suse.com
- Update to version 2.2.6 (bsc#1029223, bsc#1029224)
  + [#611] Improve logging when interface detection fails
  + [#603] Retry when get thuimbprint fails
  + [#602] Ensure host plugin calls fail gracefully
  + [#601] Handle interface resets more gracefully
  + [#600] Wait for partition before mounting
  + [#599] Correct check for heartbeat freshness
  + [#594] Fix RDMA reboot issue
  + [#588] Changed permissions for log directory
- From 2.2.5
  + [#587] Fix potential sync issue with incarnation number and cache
- From 2.2.4
  + [#579] Extend VM health status
  + [#578] Fix FreeBSD deprovision
  + [#577] Improve mount call and logging
  + [#573] Centos 7.0 hostnamectl fix
* Fri Jan 27 2017 rjschwei@rjsdomain
- Update to version 2.2.3 (bsc#1018369)
  + NSG improvements
  + CoreOS fix
  + Debian fixes
  + Apply patch from Debian
  + Unhandled errors
  + Handle ExtensionError from decide_version
  + Correct mkfile size check
  + Add a log message when primary nic is not found
  + Add telemetry event for host plugin usage
  + Fix typo in log message
  + Prevent duplicates in sysinfo
  + Add support for Match blocks in sshd config
  + Fix the logic for agent version
  + Support offline hostname changes
  + Ensure config file is updated correctly
  + Support NetworkManager leases
  + Fix password encoding
  + Minor bug fixes
  + Fix for hostnamectl
  + RHEL-7 hostname
  + Fix password encrypting failure in python 2.*
  + Handle interrupt signal
  + Fix the issues for mounting resourcedisk
- From 2.2.2
  + Cleanup SUSE config
  + Support for F5 Networks BIG-IP
  + Fix sfdisk options
  + Fix for fetch manifest
  + Fix config options for RDMA
  + Fix issue with xfs swapon
  + Add Clear Linux distro support
  + Handle deprovisioning interruption
  + Reduce goal state logging
  + Increase polling rate
  + RHUI cleanup
  + Add restart_if function for Alpine
  + Support OnHold flag
  + Fix for decode_config
  + Azure stack certificate fix
  + Enable over-provisioning support
  + Enable host plugin scenarios
  + RDMA updates
  + sfdisk logging fix
  + Big IP updates
- From 2.2.1
  + Correct the installed version check in decide_version
* Wed Oct  5 2016 rjschwei@suse.com
- Add comment to specfile clarifying the Provides directive lifespan
* Mon Oct  3 2016 rjschwei@suse.com
- Update to version 2.2.0
  + Non linear release number jump
  + Add agent-no-auto-update.patch
  + [#361] More graceful 503 handling
  + [#364] Enforce http proxy support for calls to storage
  + [#367] Stop disabling SELinux during provisioning
  + [#377] Fix partition table race condition
  + [#387] Fix latest version selection
  + [#388] Fix extension substatus structure
  + [#389] Fix shlex related update bug in Python 2.6
  + [#391] Correct behavior of register-service
  + [#398] AzureStack fixes
  + [#400] Support xfs filesystem
  + [#404] Correct service start/restart behavior
  + [#411] Support for disabling provisioning
  + [#417] Stop spamming journal with pidof dhlient related messages
  + [#418] Add goal state processor to the version output
  + [#425] Fix walinuxagent.service Want, After
  + [#439] Ensure to load latest agents
  + [#451] Correct proxy port type
* Tue Sep 13 2016 rjschwei@suse.com
- Upstream releases a tarball WALinuxAgent-%%{version} while this is
  a reminder of days gone by, as in Windows Azure, it is less confusing
  and less work if we stay with the upstream source name vs. renaming
  the tarball.
* Mon Aug 29 2016 bear454@opensuse.org
- Update to version 2.1.6 (bsc#994592)
  + improved RDMA support
  + extension state migration
  + Alpine Linux support
  + fixes for #347, #351, #353
* Tue Aug  9 2016 rjschwei@suse.com
- Require eject (bsc#992796,bsc#992797)
* Tue Jul 26 2016 bbrunner@suse.com
- Added version to Provides: WALinuxAgent
* Mon Jul 25 2016 rjschwei@suse.com
- Replace Conflicts directive with Provides, Obsoletes pair
  (bsc#990424, bsc#990489)
* Wed Jul 20 2016 rjschwei@suse.com
- Update to version 2.1.5 (bsc#989789)
  + Remove 99-azure-product-uuid.rules included from upstream
  + Remove python-azure-agent-setup.diff no longer needed
  + Remove python-azure-agent-disable-test-check-pid.diff
  + Disable tests
  - Test have been re-written such that they are expected to run in
    Azure, since we build the package in the build service 95%% fail
  + goal state processing extension
  + multi-nic improvements
  + Fix failed to mount Resource Disk #145
  + Fix PID file not updating on service restart #141
  + Fix libglibmm-2.4-1c2a dependency #133
  + Fix Creating a swap file takes too long #116
  + Fix ERROR:unicode argument without an encoding occured creating
    /var/lib/waagent/CustomData #187
  + Fix Should evaluate ssh pub key file before using it #169
  + Fix waagent fails to deploy SSH key on CentOS 7 #104
  + Fix Creating a swapfile using dd is extremely slow, please use
    fallocate on Linux #127
  + Fix ERROR:Unable to fetch Bundle URI from manifest for
    Microsoft.OSTCExtensions.LinuxDiagnostic v 2.3.4 #163
  + Fix Incorrect host route set for 168.63.129.16 on machines with
    multiple NICs (CentOS 7) #190
  + agent list trim fix
  + telemetry improvements
  + signal forwarding fix
  + self-update bug-fixes
  + poll timeout fix
  + RDMA updates
  + telemetry updates
  + use dhcp cache for CentOS
  + output buffering fix
  + rdma config files
  + sigterm forwarding
  + reduced log verbosity
  + extension manager self-update
  + multi-nic improvements
  + scvmm fixes
* Wed Jul 13 2016 rjschwei@suse.com
- Do not conflict with NetworkManager (bsc#988743)
  + we want to allow users to install the WE pattern in Azure. This is
    not possible if python-azure-agent conflicts with NetworkManager.
    Testing shows that the system is still accessible if NM is installed
    after the initial boot that sets up networking. The downside, during
    image build a user could incidentally install NM and the agent and forget
    to disable NM, an instance from this image may not be reachable.
* Tue Jul 12 2016 rjschwei@suse.com
- Apply patch  python-azure-agent-disable-test-check-pid.diff with patch
  macro to appease SLES 11 build service checks
* Sat May 21 2016 rjschwei@suse.com
- Update to version 2.1.4 (bsc#980789, bsc#980790)
  + Support for FreeBSD
  + Fix a bug for internal extension version resolving
* Mon Apr 18 2016 jgleissner@suse.com
- Renamed python-azure-agent-setup.diff to python-agent-azure-setup.diff
- Package tests in sub package
* Fri Apr 15 2016 jgleissner@suse.com
- Do not package tests (python-agent-azure-setup.diff, bsc#974899)
- Enable unit tests during build
- Disable test_check_pid (fails if /proc is not available,
  python-azure-agent-disable-test-check-pid.diff)
- Do not run sed on every file (corrupts sample_ext.zip)
- Do not mark /usr/lib/udev/rules.d files as %%config
* Tue Apr  5 2016 jgleissner@suse.com
- Include in SLE 11 and SLE 12 Public Cloud modules (bnc#973427
  fate#320692)
* Thu Feb  4 2016 rjschwei@suse.com
- Update to version 2.1.3
  + Refactor distro class
  + Fixed protocol detection on Azure Stack
  + Fix extension handling issue
  + Allow overwrite existing user
  + Decode and execute custom data
* Tue Nov 10 2015 rjschwei@suse.com
- Initial build
  + Version 2.1.2.rc2
